@@ -18,4 +18,4 @@ class AsciiBWStrategy(strategy.AsciiStrategy):
         Returns:
             str: The resulting set of chars as a unique string
         """
-        return ipe.pixel_to_ascii(pixel, colored=False)
+        return ipe.pixel_to_ascii(pixel, colored=0)
